@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.45.0"
+version = "1.46.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +27,7 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.9-r5",
+apk_tools_min_version = {"edge": "2.12.9-r6",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -721,10 +721,13 @@ deviceinfo_attributes = [
     "generate_legacy_uboot_initfs",
     "kernel_cmdline",
     "generate_bootimg",
+    "header_version",
     "bootimg_qcdt",
     "bootimg_mtk_mkimage",
     "bootimg_dtb_second",
+    "bootimg_custom_args",
     "flash_offset_base",
+    "flash_offset_dtb",
     "flash_offset_kernel",
     "flash_offset_ramdisk",
     "flash_offset_second",
